#
# spec file for package libplasma6
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.14.0
%define qt6_version 6.8.0

%define rname libplasma
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           libplasma6
Version:        6.4.2
Release:        1.0.2.1.sr20250701
Summary:        Plasma library and runtime components based upon KF6 and Qt6
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiPlatform) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Package) >= %{kf6_version}
BuildRequires:  cmake(KF6Svg) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(PlasmaActivities) >= %{_plasma6_bugfix}
BuildRequires:  cmake(PlasmaWaylandProtocols) >= 1.10.0
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6WaylandClient) >= %{qt6_version}
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
%ifarch %{arm} aarch64
BuildRequires:  pkgconfig(glesv2)
%endif
BuildRequires:  pkgconfig(wayland-client) >= 1.9
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-damage)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-xfixes)

%description
Plasma library and runtime components based upon KF6 and Qt6

%package -n libPlasma6
Summary:        Plasma 6 core libraries
Requires:       %{name}-components >= %{version}
Provides:       qt6qmlimport(org.kde.plasma.configuration)
Provides:       qt6qmlimport(org.kde.plasma.configuration.2) = 0
Provides:       qt6qmlimport(org.kde.plasma.plasmoid)
Provides:       qt6qmlimport(org.kde.plasma.plasmoid.2) = 0

%description -n libPlasma6
This package contains the core libraries needed by the Plasma framework.

%package components
Summary:        Plasma QML components
Requires:       %{name}-desktoptheme
Requires:       kf6-kdeclarative-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       plasma6-framework = %{version}
Requires:       qt6-declarative-imports >= %{qt6_version}
Provides:       plasma6-framework = %{version}
Obsoletes:      plasma6-framework < %{version}
# Only in KUF before 6.0
Provides:       plasma6-framework-components = %{version}
Obsoletes:      plasma6-framework-components < %{version}

%description components
Plasma QML and runtime components based upon KF6 and Qt6

%package desktoptheme
Summary:        Desktop theme files usable by Plasma 5 and Plasma 6
# Can be used by both plasma 5 and 6
Conflicts:      plasma-framework < 5.110.0
Provides:       plasma-framework-desktoptheme = %{version}
Obsoletes:      plasma-framework-desktoptheme < %{version}
# Only in KUF before 6.0
Provides:       plasma6-framework-desktoptheme = %{version}
Obsoletes:      plasma6-framework-desktoptheme < %{version}

%description desktoptheme
Desktop themes usable by both plasma 5 and plasma 6.

%package devel
Summary:        Plasma library and runtime components
Requires:       libPlasma6 = %{version}
Requires:       plasma6-framework >= %{version}
Requires:       plasma6-framework-components = %{version}
Requires:       cmake(KF6Package) >= %{kf6_version}
Requires:       cmake(KF6WindowSystem) >= %{kf6_version}
Requires:       cmake(Qt6Gui) >= %{qt6_version}
Requires:       cmake(Qt6Quick) >= %{qt6_version}
Conflicts:      plasma-framework-devel
# Only in KUF before 6.0
Provides:       plasma6-framework-devel = %{version}
Obsoletes:      plasma6-framework-devel < %{version}

%description devel
Plasma library and runtime components based upon KF6 and Qt6

%package -n libPlasma6-lang
Summary:        Translations for package libPlasma6
Requires:       libPlasma6 = %{version}
Provides:       libPlasma6-lang-all = %{version}
BuildArch:      noarch
# Only in KUF before 6.0
Provides:       plasma6-framework-lang = %{version}
Obsoletes:      plasma6-framework-lang < %{version}

%description -n libPlasma6-lang
Provides translations for the "libPlasma6" package.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang libplasma6

%pre -n libPlasma6
# boo#1221405: When upgrading from plasma5-workspace to plasma6-workspace,
# preun of the previous package does not know it's actually an upgrade
# (because the package name differs) and it does systemctl --disable --now
# on all units, which immediately kills the session :-( The old preun can't be
# disabled so a hack is needed: Set RefuseManualStop=true on all plasma-* user
# units for the entirety of the transaction. This package should be early
# enough during the transaction as various plasma6 packages require it.
# Only perform the workaround if systemd is running and plasma5-workspace
# is currently still installed.
if [ -x /usr/lib/systemd/systemd-update-helper ] && [ -d /run/systemd/system ] \
   && [ -e /usr/share/qlogging-categories5/plasma-workspace.categories ]; then
  for unit in $(ls /usr/lib/systemd/user/ | grep '^plasma-.*\.service$'); do
    mkdir -p "/run/systemd/user/${unit}.d"
    echo -e '[Unit]\nRefuseManualStop=true' > "/run/systemd/user/${unit}.d/boo1221405.conf"
  done
  touch /run/plasma-boo1221405-workaround
  /usr/lib/systemd/systemd-update-helper user-reload || :
fi

%ldconfig_scriptlets -n libPlasma6

%posttrans -n libPlasma6
# Remove the temporary dropin files from pre again.
if [ -e /run/plasma-boo1221405-workaround ]; then
  rm /run/systemd/user/plasma-*.service.d/boo1221405.conf
  /usr/lib/systemd/systemd-update-helper user-reload || :
  rm /run/plasma-boo1221405-workaround
fi

%files components
%{_kf6_debugdir}/plasma-framework.categories
%{_kf6_debugdir}/plasma-framework.renamecategories
%{_kf6_plugindir}/kf6/kirigami/
%{_kf6_plugindir}/kf6/packagestructure/
%{_kf6_qmldir}/org/kde/kirigami/
%{_kf6_qmldir}/org/kde/plasma/

%files -n libPlasma6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libPlasma.so.*
%{_kf6_libdir}/libPlasmaQuick.so.*

%files desktoptheme
%{_kf6_plasmadir}/desktoptheme/

%files devel
%doc %{_kf6_qchdir}/Plasma.*
%{_kf6_cmakedir}/Plasma/
%{_kf6_cmakedir}/PlasmaQuick/
%{_includedir}/Plasma/
%{_includedir}/PlasmaQuick/
%{_kf6_libdir}/libPlasma.so
%{_kf6_libdir}/libPlasmaQuick.so
%{_kf6_sharedir}/kdevappwizard/

%files -n libPlasma6-lang -f libplasma6.lang

%changelog
* Tue Jul  1 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.4.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.4.2
- Changes since 6.4.1:
  * Update version for new release 6.4.2
  * theme: Add active, positive, neutral, negative backgrounds colors
* Tue Jun 24 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.4.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.4.1
- Changes since 6.4.0:
  * Update version for new release 6.4.1
* Thu Jun 12 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.4.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.4.0
- Changes since 6.3.91:
  * Update version for new release 6.4.0
  * Achieve WCAG AA text contrast for labels
  * Drop unused KCMUtils dependency
  * plasmaextracomponents: fix icon-less PlaceholderMessage
  * plasmaquick/containmentitem: remove uncategorized warnings
* Thu May 29 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.91
- Changes since 6.3.90:
  * Update version for new release 6.3.91
  * Fix drag and drop of item on containments (kde#460056)
  * drag and drop: delete the menu if there are no actions to show (kde#502479)
  * Fix crash in drop job (kde#504355)
  * plasma/pluginloader: actually use pluginName when loading plugins (kde#504343)
* Mon May 19 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.3.90
- Too many changes to list here
* Tue May  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.5
- Changes since 6.3.4:
  * update version for new release
  * Use proper attached properties for Kirigami colorset
  * update version for new release
* Wed Apr  2 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.3.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/6/6.3.4
- Changes since 6.3.3:
  * Use Disabled Text color when needed (kde#501633)
  * update version for new release
* Tue Mar 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.3
- Changes since 6.3.2:
  * update version for new release
  * plasmaquick: don't use KWinInfo in Wayland dialogs (kde#500394)
  * ContainmentItem: delete wallpaper item immediately to fix crash (kde#499944)
  * ShadowedLabel: Set z-index on fallback background
  * update version for new release
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
  * WindowThumbnail: remove uncategorized debug message
  * Applet: possibility to cleanup transient applets (kde#498175,kde#404641)
  * Add bool immutable() shortcut
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * update version for new release
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
  * ButtonContent: Center the GridLayout itself
  * Make mnemonics work again with Qt < 6.8 without animateClick
  * plasmaquick: Avoid setting window position for OSD surfaces
  * Immediately update popup position upon setting margin
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Too many changes to list here
* Fri Jan 10 2025 Franck Bui <fbui@suse.com>
- In some corner cases, systemd user instances might be in failing state and
  attempts to reload them (via the 'systemd-update-helper' private script) may
  fail. Avoid to abort the upgrade process in these cases (bsc#1234904).
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
  * Fix wallpaper templates
  * Always ensure setDestroyed propagates to all children applets
  * AppletQuickItem: Better handle missing mainScript
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
  * FlatButtonBackground: Fix background disappearing when pressing checkable ToolButton Pressed seems to go false, causing the animation to run to hide the background, and then checked becomes true immediately after, restoring the background. Using a NumberAnimation instead will interrupt itself and make no visible change.
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
  * Only constrain popups to parent windows when there's enough space to do so (kde#494338)
  * Fix PlasmaWindow type registration (kde#494475)
  * update version for new release
  * containment: emit screen geometry change correctly
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * WindowThumbnail: fix crash when failing to resolve GLX_EXT_texture_from_pixmap functions
  * Apply restricted geometry after anchor window constraints
  * Handle floating point position and size for PlasmoidHeading logic (kde#492436)
  * Use delayed binding for ToolTip visibility (kde#475646)
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Too many changes to list here
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
  * plasmaquick/appletpopup: don't resize in response to min/max size with invalid sizes (kde#490732)
  * Spinbox: use more appropriate icons for decrease and increase buttons (kde#491312)
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
  * containmentitem.cpp: Do not set dropJob parent to m_dropMenu (kde#484674)
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
  * On applet destroyed go out of configure mode (kde#488977)
  * Workaround to possible infinite reize loops (kde#488974)
  * quick/dialogbackground: Ensure we delete the SVG item (kde#486743)
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
  * plasma/pluginloader: Repair loading plasmoid plugins on add from explorer (kde#488592)
  * Don't delete containment if appletDelete is on one of children
  * Don't double delete PlasmoidItems
  * update version for new release
  * Init at componentComplete
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
  * Applet: run full Applet::save when a config value changes (kde#481113)
  * Revert "Applet: Drop mostly dead code to save config"
  * update version for new release
  * private/ButtonContent: Make buttons' icon colors settable externally (kde#483375)
  * Always limit tooltip size to screen size (kde#487742)
  * Add temporary faux api to allow popups to constrain popup placement
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
  * More robust against malformed hints (kde#487230)
  * Workaround setMinimumSize not resizing (kde#485456,kde#480722)
  * clock.svg: remove empty groups that cause warnings
  * Sync config to disk when values change (kde#481085,kde#482469,kde#482090,kde#481113,kde#482773,kde#483083)
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * containmentview: Remove QueuedConnection from setContainment
  * PlasmaTheme: only sync colors when parent item is visible
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
  * Do not activate containment when one of its applet is activated (kde#483941,kde#479084)
* Sat Mar 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Work around %%preun in installed packages killing the session
  during upgrade (boo#1221405)
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * ContainmentItem: set correct constraints when wallpaper is ready (kde#482267)
  * ContainmentItem: report correct isLoading status
  * Remove old focus workaround (kde#481967)
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
  * Show a more specific error message for incompatible widgets (kde#481328)
  * Don't show arrow for icon-only buttons
* Tue Mar  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Obsolete Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Too many changes to list here
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * Make WindowThumbnail build against Qt6 as well
  * Plasmacomponents2 Highlight: add explicit id
  * Highlight: change hover: property to hovered:
  * Don't install the heading SVG in breeze-light and breeze-dark Plasma themes
  * AppletInterface: Add `self` property which just returns `this`
  * Allow applets to have empty json metadata & use KPackage's metadata instead
  * Do not compute sizes within dialogs when they're not visible
  * Port dateengine away from inperformant KPluginInfo hack
  * Improve documentation of PlasmaExtras.Highlight
  * Factor out QML module URI string
  * Update documentation regarding PlasmaExtras.Highlight
  * Adapt to the deprecation of qmlRegisterInterface in Qt6
  * Add default switch statement
  * Add power profile icons (kde#449475)
  * Fix Plasmoid attached property look-up on Config objects (kde#451482)
  * Fix potential null parent access
  * Break recursion when checking compact representation
  * Use generic breeze-styled arrow in Plasma style
  * Port to PlasmaExtras version of Highlight
  * Hardcode keyboard shortcut in SearchField for now
  * Add ActionTextField, SearchField, and PasswordField
  * PC3: Remove unreachable code in Svg item from DefaultListItemBackground
  * AppletQuickItem: Ensure we provide the attached property when we have it
  * Port from using plasmoid to Plasmoid
  * Calendar: Draw highlight below the text (kde#451209)
  * Use PACKAGE_CMAKE_INSTALL_PREFIX before any find_dependency() calls
  * Move Highlight from PlasmaComponents 2.0 to PlasmaExtras
  * Introduce PLASMA_NO_CONTEXTPROPERTIES to disable Plasma QML context properties
* Wed Jan 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Rename to libplasma6
- Merge main package into -components
* Wed Jan 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Init plasma6-framework
